#
# spec file for package kf6-ktexteditor
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt6_version 6.7.0

%define rname ktexteditor
# Full KF6 version (e.g. 6.13.0)
%{!?_kf6_version: %global _kf6_version %{version}}
# Last major and minor KF6 version (e.g. 6.0)
%{!?_kf6_bugfix_version: %define _kf6_bugfix_version %(echo %{_kf6_version} | awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           kf6-ktexteditor
Version:        6.13.0
Release:        1.1
Summary:        Embeddable text editor component
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{_kf6_bugfix_version}
BuildRequires:  pkgconfig
BuildRequires:  cmake(EditorConfig)
BuildRequires:  cmake(KF6Archive) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6Config) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6GuiAddons) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6I18n) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6KIO) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6Parts) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6Sonnet) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6SyntaxHighlighting) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6WindowSystem) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6PrintSupport) >= %{qt6_version}
BuildRequires:  cmake(Qt6Qml) >= %{qt6_version}
BuildRequires:  cmake(Qt6TextToSpeech) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  cmake(Qt6Xml) >= %{qt6_version}
BuildRequires:  pkgconfig(libgit2)
Requires:       kf6-syntax-highlighting >= %{_kf6_bugfix_version}

%description
KTextEditor provides a text editor component that can be embedded in
applications, either as a KPart or using the KF6::TextEditor library.

%package -n libKF6TextEditor6
Summary:        Embeddable text editor component
Requires:       kf6-ktexteditor >= %{version}

%description -n libKF6TextEditor6
KTextEditor provides a text editor component that can be embedded in
applications, either as a KPart or using the KF6::TextEditor library.

%package devel
Summary:        Header files for ktexteditor, an embeddable text editor component
Requires:       libKF6TextEditor6 = %{version}
Requires:       cmake(KF6Parts) >= %{_kf6_bugfix_version}
Requires:       cmake(KF6SyntaxHighlighting) >= %{_kf6_bugfix_version}

%description devel
KTextEditor provides a text editor component that can be embedded in
applications, either as a KPart or using the KF6::TextEditor library.

This subpackage provides the header files.

%lang_package

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6 -DBUILD_QCH:BOOL=TRUE \
           -DENABLE_KAUTH:BOOL=FALSE

%kf6_build

%install
%kf6_install

%fdupes %{buildroot}

%find_lang ktexteditor6

%ldconfig_scriptlets -n libKF6TextEditor6

%files
%{_kf6_debugdir}/ktexteditor.categories
%{_kf6_debugdir}/ktexteditor.renamecategories
%{_kf6_bindir}/ktexteditor-script-tester6
# TODO split
%dir %{_kf6_plugindir}/kf6/parts
%{_kf6_plugindir}/kf6/parts/katepart.so

%files -n libKF6TextEditor6
%license LICENSES/*
%doc README.md
%{_kf6_libdir}/libKF6TextEditor.so.*

%files devel
%doc %{_kf6_qchdir}/KF6TextEditor.*
%{_kf6_cmakedir}/KF6TextEditor/
%{_kf6_includedir}/KTextEditor/
%{_kf6_libdir}/libKF6TextEditor.so
%{_kf6_sharedir}/kdevappwizard/templates/ktexteditor6-plugin.tar.bz2

%files -n kf6-ktexteditor-lang -f ktexteditor6.lang

%changelog
* Sat Apr  5 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.13.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.13.0
- Changes since 6.12.0:
  * Fix build with Qt 6.10
  * try to improve test stability
  * don't move the cursor to the current drop location for file drops (kde#501618)
  * Try to flush less often to disk (kde#501508)
  * Adapt unit test to changes in KF::SyntaxHighlighting
  * It compiles fine without kf6.12 deprecated methods
  * Add Text to Speech actions to context menu
  * cut down to right integer size
  * use _commit for safer swap files on Windows
  * ensure we don't run into corner cases in Qt for font sizes (kde#500766)
  * KateScrollBar: Add minimap actions to context menu
  * trigger dictionary load
  * Update dependency version to 6.13.0
* Tue Mar 11 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.12.0
- Changes since 6.11.0:
  * Update dependency version to 6.12.0
  * remove static_assert to avoid compiler warnings
  * Add "gc" motion for vim to Toggle Comment (kde#490195)
  * Fix boundary condition in argument hint navigation
  * Fix line no info tooltip persists on right click
  * Improve wording of Copy as HTML whatsthis
  * Add "Copy as HTML" to context menu
  * don't reset revision on reload but increment it (kde#499311)
  * katedocument: Optimize mimeType
  * compute at least inside cursorToX with floats (kde#499669)
  * Fix scrolling to search results in wrapped long lines (kde#448765)
  * renderer: simplify text ranges comparison function
  * Add direct camel/subword movement actions
  * Update version to 6.12.0
* Sat Feb  8 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.11.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.11.0
- Changes since 6.10.0:
  * Update dependency version to 6.11.0
  * try to improve test stability
  * don't sort already sorted newBlock->m_cursors
  * use one newBlock->m_lines.insert instead of many newBlock->m_lines.push_back
  * Adjusted theme config page margins
  * Allow disabling 'cycle through bookmarks' behaviour (kde#499268)
  * avoid text hint if already triggered when popup menu is requested (kde#499092)
  * Fix KateCompletionTree width (kde#498244)
  * Add xml/yaml linting
  * autotests/src/swapfiletest.cpp - include <QTest>
  * ensure we do not kill symlinks (kde#498589)
  * stop hover timer when cursor changes
  * CI: Add linux-qt6-next build
  * Store Search/Replace history in state config
  * Update version to 6.11.0
* Thu Jan  9 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.10.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.10.0
- Changes since 6.9.0:
  * Update dependency version to 6.10.0
  * Fix default shortcuts for mac os
  * rewrite Kate::TextBlock::mergeBlock m_cursors merging code
  * use one targetBlock->m_lines.insert instead of many targetBlock->m_lines.push_back
  * add testNoFlippedRange and testBlockSplitAndMerge to movingrange_test
  * Preprocess lineEndings before pasting
  * "Paste From File" feature for Kate to select a file and insert it's contents into the current file (kde#496902)
  * Remove unnecessary multicursor clipboard code
  * Try to split clipboard text across multiple cursors when pasting (kde#497863)
  * Optimize kill lines for large number of cursors
  * Fix full line selection behaviour of the C++ versions of the editing commands
  * remove not needed include
  * ensure content like from document doesn't make the dialog size explode (kde#497328)
  * store QTextLayout inline
  * Update version to 6.10.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.9.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.9.0
- Changes since 6.8.0:
  * Update dependency version to 6.9.0
  * sort and remove duplicates in outRanges in Kate::TextBuffer::rangesForLine
  * Add test case for line unwrapping crash
  * don't leave non-multiblock Kate::TextRange in m_buffer->m_multilineRanges
  * don't crash on insert at lastLine + 1 (kde#496612)
  * avoid closeUrl() call
  * Clear all references/uses of aboutToDeleteMovingInterfaceContent
  * Align completion with the word being completed (kde#485885)
  * try to relax unstable test
  * Use a QLabel for scrollbar linenumbers tooltip
  * Add functions for jumping to next/prev blank line
  * Disable ENABLE_KAUTH_DEFAULT on Haiku also
  * Remove misleading dead code
  * Fix crash if feedback or dyn attr is cleared before deletion (kde#495925)
  * Fix ranges with dynamic attribute dont notify deletion
  * Deprecate aboutToDeleteMovingInterfaceContent
  * Remove m_ranges from buffer
  * Dont take ownership of the MovingRange/MovingCursor
  * buffer: Remove m_invalidCursors
  * allow shifted numbers for Dvorak and Co. (kde#388138)
  * keep hinting as set by the user (kde#482659)
  * Update version to 6.9.0
* Mon Nov  4 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.8.0
- Changes since 6.7.0:
  * Vi mode: Don't infinite loop in searcher
  * Update dependency version to 6.8.0
  * remove unused var
  * fix ignores
  * less deprecated stuff used
  * Don't temporarily clear document URL during openUrl()
  * Only discard completion if the cursor was at the end of line
  * Update git blame ignore file
  * Reformat code with clang-format
  * Fix implicit conversion of Qt::Key in Qt 6.9
  * Try to avoid unwanted completions
  * fix session restore of file type (kde#492201)
  * Make ViewPrivate::displayRangeChanged public
  * Set DocumentPrivate::m_reloading to false only if loading
  * Give a more proper name to the test
  * Fix multiblock range handling when unwrapping line (kde#494826)
  * Fix line removal not handled properly in KateTemplateHandler (kde#434093)
  * Update version to 6.8.0
  * Inline blocksize into buffer
  * Improve MovingRangeTest::benchCheckValidity
  * Improve TextRange::checkValidity performance
  * do all testing in clean temp dirs
  * Add a swap file test
  * add benchmarks for moving stuff
  * Use std::vector for cursor storage
  * Allow disabling editorconfig (kde#471008)
* Mon Oct  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.7.0
- Changes since 6.6.0:
  * Update dependency version to 6.7.0
  * Port away from deprecated KPluralHandlingSpinBox
  * Fix unexpected space indentation in Go var group (kde#487054)
  * Read dir kateconfig on view creation (kde#489600)
  * Fix pressing <ENTER> on } inserts two lines instead of one (kde#479717)
  * Dont remove trailing spaces in markdown by default (kde#451648)
  * Multicursors: Avoid indenting the sameline twice
  * blockmode: repair indent when the cursor is in the first column
  * Multicursor: Fix indent with multiple cursors
  * with latest syntax definition, more tests pass for ruby
  * use more views
  * avoid double signal emission
  * less deprecated calls, works locally
  * Store multiline ranges spanning multiple blocks in TextBuffer
  * Remove MovingRange caching in TextBlock
  * add hint the file might got moved (kde#476071)
  * Dont create selection highlights with multiple selections
  * Optimize killLine for multiple cursors
  * completion: Allow async population of documentation
  * more const to avoid wrong use of these members
  * ensure modify the renderer that is used for printing (kde#465526)
  * Fix text insertion with multiple cursors at same position. (kde#492869)
  * Add command names for "Remove Spaces" and "Keep Extra Spaces"
  * Minimap now follows the theme also for search matches
  * Run clang-format
  * Fix merging of selections in opposite directions
  * Fix secondary cursor at boundary of selection doesn't get removed
  * Fix warnings
  * Update version to 6.7.0
* Sat Sep  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.6.0
- Changes since 6.5.0:
  * Update version to 6.6.0
  * Make tests a bit faster
  * Fix clashing and missing keyboard accelerators
  * Add help texts for new editing commands
  * Move sort implementation to C++ (kde#478250)
  * Move natsort to C++ and implement it using QCollator
  * Move the sortuniq, uniq implementation to C++ (kde#478250)
  * read and write font features to config
  * Fix doc.text() when first block is empty
  * Fix block splitting
  * try to make test more robust
  * Restore previous indentation test mode based on individual files
  * Store startlines in the buffer instead of block
  * doc: Fix code example for plugin hosting
  * no 10 second timeouts, the CI is not that consistent fast
  * try to make test more stable
  * improve encoding detection (kde#487594)
  * fix grouping on config dialog page (kde#490617)
  * Optimize cursorToOffset
  * Dont indent on tab when in block selection mode (kde#448695)
  * Fix selection printing (kde#415570)
* Mon Aug  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.5.0
- Changes since 6.4.0:
  * Update dependency version to 6.5.0
  * Fix drag pixmap with wrapped lines (kde#476979)
  * Add actions to convert spaces to tabs and vice versa (kde#456736)
  * use ktexteditor-script-tester6 for javascript tests
  * fix -Woverflow warning with gcc
  * templates: Remove one level of nesting
  * Ignore buffer signals in completion on undo/redo
  * cursorToOffset: remove unnecessary line variable
  * Fix formatting
  * Update version to 6.5.0
  * src/view/kateview.cpp (KTextEditor::ViewPrivate::setupActions) : Fix typo in m_toggleShowSpace and m_toggleDynWrap whatsThis text.
  * Treat 0x0000 to 0x001F as non-printable
  * add action to quick toggle space visibility
* Tue Jul  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.4.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.4.0
- Changes since 6.3.0:
  * add a tool to test javascript scripts
  * fix JS API result of view.executeCommand()
  * kateregexpsearch: fix FAST_DEBUG
  * API documentation: fix typo on kte_design page
  * add action to popy the current file name and line (kde#488027)
  * prefer even indent sizes (kde#474505)
  * try different way to read file for digest
  * remove gradient, looks ugly
  * add missing :, are there for all other entries
  * don't remember encoding if known to be broken (kde#445015)
  * ensure we don't keep old session config keys (kde#486648)
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- Changes since 6.2.0:
  * ensure the color name text is visible (kde#487068)
  * ensure we not reset the dynamic word wrap state (kde#487216)
  * Port to KStandardActions
  * Never remove trailing spaces on diff file type
  * Remove explicit maintainer from metainfo
  * Screenshot dialog: support drag of image
  * make tests independent of the user's environment
  * Modernize use designated init
  * do not display diff result in script tests when -silent is used
  * fix raw string indentation with cstyle + C++
  * Use ellipsis character instead of three dots in UI strings
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- Changes since 6.1.0:
  * Fix caret painting for inline notes at the end of line
  * KateCompletionWidget: Mark function static
  * KateCompletionModel: remove useless std::as_const
  * run more tests offscreen
  * Fix performance with many cursors in a large line
  * fix test expectations
  * fix crashs and OOM on load with encoding failures (kde#486195)
  * a11y: Improve tab order for "Appeareance" -> "Borders"
  * a11y: Set "Line Height Multiplier" buddy
  * Fix broken navigation in completion widget with multiple views
  * Fix clicking in completion
  * fix textInsertedRange signal for insertText behind last line (kde#483363)
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Changes since 6.0.0:
  * update version for new release
  * Fix argument hint placement
  * Dont use activeView as save dialog parent (kde#484466)
  * ensure only set stuff is saved
  * Dont write useless entries to session config
  * all tests work offscreen in the CI
  * try to avoid crash in destructor
  * try more offscreen
  * ensure we don't crash if no view is active
  * kateviewinternal: accept surrogate category character (kde#482864)
  * use test mode with e.g. own temporary config files
  * avoid using QChar constructor for key codes (kde#483631)
  * remove obsolete option code
  * Remove focus frame option (kde#483218)
  * Fix duplicate folds occuring
  * Fix support for folding in vi normal mode
  * adapt test to hinting change
  * Set full hinting instead to ensure the letters are aligned properly (kde#482659)
  * try to save changes
  * Optimize a mark-restoring condition after document reload
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * add setRange overloads
  * be consistent, the wrapper never uses const to hand out refs/pointers
  * update version for new release
  * Include QWidgetList
  * add widgets api
  * ensure we support unicode in patterns (kde#462437)
  * fix quadratic checks
  * fix handling for full scanned lines
  * split lines early (kde#479073)
  * more line wrapping tests
  * Dont apply clipping with selections (kde#475378)
  * Fix selection rendering with custom line height (kde#475378)
  * Plugin template: fix plugin installation path
  * Plugin template: bump min KF dep to match initial KF6 release
  * Fix dyn word wrap indicator validation check (kde#480831)
  * util-scripts: Use setText when working with whole document
  * fix formatting
  * check longestLineLoaded, too
  * add test for setLineLengthLimit
  * use cursorToOffset for accessibility events
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Sat May 27 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-ktexteditor
